from data.neuro.Rama_prod_classify_class import Rama_prod_classify_class
from data.neuro.local_models import *
from data.neuro.models import RAMA_PROD_CLASSIFY_MODEL_ADDRESS, RAMA_PROD_CLASSIFY_MODEL_ADDRESS_2, \
    RAMA_PROD_CLASSIFY_MODEL_ADDRESS_3


class Danila_rama_classify_prod:
    def __init__(self, local, yolov5_dir, rama_classify_model):
        yolo_path = yolov5_dir
        if local:
            if rama_classify_model == 1:
                rama_prod_classify_model_path = LOCAL_RAMA_PROD_CLASSIFY_MODEL_ADDRESS
            elif rama_classify_model == 2:
                rama_prod_classify_model_path = LOCAL_RAMA_PROD_CLASSIFY_MODEL_ADDRESS_2
                self.size = 512
            elif rama_classify_model == 3:
                rama_prod_classify_model_path = LOCAL_RAMA_PROD_CLASSIFY_MODEL_ADDRESS_3
                self.size = 480
            elif rama_classify_model == 4:
                rama_prod_classify_model_path = LOCAL_RAMA_PROD_CLASSIFY_MODEL_ADDRESS_4
                self.size = 576
            elif rama_classify_model == 5:
                rama_prod_classify_model_path = LOCAL_RAMA_PROD_CLASSIFY_MODEL_ADDRESS_5
                self.size = 576
        else:
            if rama_classify_model == 1:
                rama_prod_classify_model_path = RAMA_PROD_CLASSIFY_MODEL_ADDRESS
            elif rama_classify_model == 2:
                rama_prod_classify_model_path = RAMA_PROD_CLASSIFY_MODEL_ADDRESS_2
                self.size = 512
            elif rama_classify_model == 3:
                rama_prod_classify_model_path = RAMA_PROD_CLASSIFY_MODEL_ADDRESS_3
                self.size = 480
        print('reading and loading - RAMA_PROD_CLASSIFY_MODEL')
        self.rama_prod_classify_model = Rama_prod_classify_class(local, rama_prod_classify_model_path, yolo_path)

    def rama_classify(self, img):
        rama_prod_conf = self.rama_prod_classify_model.classify(img, self.size)
        return rama_prod_conf



from data.neuro.Detail_classify_class import Detail_classify_class
from data.neuro.Detail_classify_yolo_dop_yolo_dop_CNN import Detail_classify_yolo_dop_yolo_dop_CNN
from data.neuro.local_models import *
from data.neuro.models import DETAIL_CLASSIFY_MODEL_ADDRESS, DETAIL_CLASSIFY_MODEL_ADDRESS_2, \
    DETAIL_CLASSIFY_YOLO_MODEL_ADDRESS, DETAIL_CLASSIFY_BALKA_MODEL_ADDRESS, DETAIL_CLASSIFY_RAMA_MODEL_ADDRESS, \
    DETAIL_CLASSIFY_VAGON_MODEL_ADDRESS
from data.result.Text_cut_recognize_result import Text_cut_recognize_result
from data.result.Text_recognize_result import Text_recognize_result


class Danila_detail_yolo_dop_yolo_dop_CNN():
    def __init__(self, local, yolo_dir, CNN_model_version):
        if local:
            if CNN_model_version == 1:
                detail_classify_model_path = LOCAL_DETAIL_CLASSIFY_MODEL_ADDRESS_2
            print('reading and loading - DETAIL_CLASSIFY_MODEL')
            self.detail_classify_model = Detail_classify_yolo_dop_yolo_dop_CNN(local, yolo_dir= yolo_dir,
                                                                               detail_classify_CNN=detail_classify_model_path,
                                                                               detail_classify_yolo= LOCAL_DETAIL_CLASSIFY_YOLO_MODEL_ADDRESS,
                                                                               balka_detect= LOCAL_DETAIL_CLASSIFY_BALKA_MODEL_ADDRESS,
                                                                               rama_detect= LOCAL_DETAIL_CLASSIFY_RAMA_MODEL_ADDRESS,
                                                                               vagon_detect= LOCAL_DETAIL_CLASSIFY_VAGON_MODEL_ADDRESS)
        else:
            if CNN_model_version == 1:
                detail_classify_model_path = DETAIL_CLASSIFY_MODEL_ADDRESS_2
            print('reading and loading - DETAIL_CLASSIFY_MODEL')
            self.detail_classify_model = Detail_classify_yolo_dop_yolo_dop_CNN(local, yolo_dir= yolo_dir,
                                                                               detail_classify_CNN=detail_classify_model_path,
                                                                               detail_classify_yolo= DETAIL_CLASSIFY_YOLO_MODEL_ADDRESS,
                                                                               balka_detect= DETAIL_CLASSIFY_BALKA_MODEL_ADDRESS,
                                                                               rama_detect= DETAIL_CLASSIFY_RAMA_MODEL_ADDRESS,
                                                                               vagon_detect= DETAIL_CLASSIFY_VAGON_MODEL_ADDRESS)




    def detail_classify(self, img):
        class_detail_conf = self.detail_classify_model.classify(img)
        detail = Text_recognize_result(
            Text_cut_recognize_result(class_detail_conf.class_detail.name, class_detail_conf.conf))
        return detail



from danila.danila_balka.danila_balka_text_recognize.danila_balka_text_recognize_altai_work import \
    Danila_balka_text_recognize_altai_work
from danila.danila_balka.danila_balka_text_recognize.danila_balka_text_recognize_model_3 import \
    Danila_balka_text_recognize_model_3
from danila.danila_balka.danila_balka_text_recognize.danila_balka_text_recognize_model_4 import \
    Danila_balka_text_recognize_model_4
from danila.danila_balka.danila_balka_text_recognize.danila_balka_text_recognize_work import \
    Danila_balka_text_recognize_work
from data.result.balka_prod import Balka_Prod


class Danila_balka_text_recognize_init_4:
    def __init__(self, yolov5_dir):
        danila_balka_text_recognize_model = Danila_balka_text_recognize_model_4()
        model = danila_balka_text_recognize_model.get_model(yolov5_dir)
        model_altai = danila_balka_text_recognize_model.get_model_altai(yolov5_dir)
        self.prod_models = {}
        for balka_prod in Balka_Prod:
            if balka_prod == Balka_Prod.altai:
                self.prod_models[balka_prod] = Danila_balka_text_recognize_altai_work(
                    text_recognize_model=model_altai
                )
            else:
                self.prod_models[balka_prod] = Danila_balka_text_recognize_work(
                    text_recognize_model=model,
                    prod_coefficients=danila_balka_text_recognize_model.get_prod_coefficients(balka_prod)
                )

    def balka_text_recognize(self, balka_prod, img_cut, image_text_areas):
        return self.prod_models[balka_prod].balka_text_recognize(balka_prod, img_cut, image_text_areas)




from danila.danila_rama.danila_rama_text_recognize.danila_rama_text_recognize_model_1 import \
    Danila_rama_text_recognize_model_1
from danila.danila_rama.danila_rama_text_recognize.danila_rama_text_recognize_model_2 import \
    Danila_rama_text_recognize_model_2
from danila.danila_rama.danila_rama_text_recognize.danila_rama_text_recognize_model_3 import \
    Danila_rama_text_recognize_model_3
from danila.danila_rama.danila_rama_text_recognize.danila_rama_text_recognize_work import Danila_rama_text_recognize_work
from data.result import Rama_prod



class Danila_rama_text_recognize_init_4:
    def __init__(self, yolov5_dir):
        danila_rama_text_recognize_model_1 = Danila_rama_text_recognize_model_1()
        model_1 = danila_rama_text_recognize_model_1.get_model(yolov5_dir)
        danila_rama_text_recognize_model_2 = Danila_rama_text_recognize_model_2()
        model_2 = danila_rama_text_recognize_model_2.get_model(yolov5_dir)
        danila_rama_text_recognize_model_3 = Danila_rama_text_recognize_model_3()
        model_3 = danila_rama_text_recognize_model_3.get_model(yolov5_dir)
        self.prod_models = {}
        for rama_prod in Rama_prod.Rama_Prod:
            if rama_prod == Rama_prod.Rama_Prod.balakovo:
                self.prod_models[rama_prod] = Danila_rama_text_recognize_work(
                    text_recognize_model=model_2,
                    prod_coefficients=danila_rama_text_recognize_model_2.get_prod_coefficients(rama_prod)
                )
            elif rama_prod == Rama_prod.Rama_Prod.ruzhimmash:
                self.prod_models[rama_prod] = Danila_rama_text_recognize_work(
                    text_recognize_model=model_2,
                    prod_coefficients=danila_rama_text_recognize_model_2.get_prod_coefficients(rama_prod)
                )
            elif rama_prod == Rama_prod.Rama_Prod.uralvagon:
                self.prod_models[rama_prod] = Danila_rama_text_recognize_work(
                    text_recognize_model=model_1,
                    prod_coefficients=danila_rama_text_recognize_model_1.get_prod_coefficients(rama_prod)
                )
            else:
                self.prod_models[rama_prod] = Danila_rama_text_recognize_work(
                    text_recognize_model=model_3,
                    prod_coefficients=danila_rama_text_recognize_model_3.get_prod_coefficients(rama_prod)
                )

    def rama_text_recognize(self, rama_prod, img_cut, image_text_areas):
        return self.prod_models[rama_prod].rama_text_recognize(img_cut, image_text_areas)

    def get_number_length(self, rama_prod):
        return self.prod_models[rama_prod].prod_coefficients.number_coefficients.length



import hashlib
import json
import os
from datetime import datetime

import cv2
import torch
from tensorflow import keras
import numpy as np

from data.neuro.models import *
from data.result.Class_im import *
import zipfile
import requests
from urllib.parse import urlencode

class Detail_classify_yolo_dop_yolo_dop_CNN:
    def __init__(self, local, yolo_dir, detail_classify_CNN, detail_classify_yolo, balka_detect, rama_detect, vagon_detect):
        if local:
            self.detail_classify_CNN_model = keras.models.load_model(detail_classify_CNN)
            self.detail_classify_yolo_model = torch.hub.load(yolo_dir, 'custom', detail_classify_yolo, source='local')
            self.rama_detect_model = torch.hub.load(yolo_dir, 'custom', rama_detect, source='local')
            self.balka_detect_model = torch.hub.load(yolo_dir, 'custom', balka_detect, source='local')
            self.vagon_number_detect_model = torch.hub.load(yolo_dir, 'custom', vagon_detect, source='local')
        else:
            base_url = 'https://cloud-api.yandex.net/v1/disk/public/resources/download?'

            public_key = detail_classify_CNN  # Сюда вписываете вашу ссылку
            # Получаем загрузочную ссылку
            final_url = base_url + urlencode(dict(public_key=public_key))
            response = requests.get(final_url)
            download_url = response.json()['href']

            # Загружаем файл и сохраняем его
            download_response = requests.get(download_url)
            # print(download_response.content)

            # print(download_response.content)
            with open('detail_classify_model.zip', 'wb') as f:
                f.write(download_response.content)

            with zipfile.ZipFile('detail_classify_model.zip', 'r') as zip_ref:
                zip_ref.extractall()
            self.detail_classify_CNN_model = keras.models.load_model('detail_classify_model.h5')

            base_url = 'https://cloud-api.yandex.net/v1/disk/public/resources/download?'
            public_key = detail_classify_yolo  # Сюда вписываете вашу ссылку
            # Получаем загрузочную ссылку
            final_url = base_url + urlencode(dict(public_key=public_key))
            response = requests.get(final_url)
            download_url = response.json()['href']
            # Загружаем файл и сохраняем его
            download_response = requests.get(download_url)
            zip_path = 'detail_classify.zip'
            # print(download_response.content)
            with open(zip_path, 'wb') as f:
                f.write(download_response.content)

            with zipfile.ZipFile(zip_path, 'r') as zip_ref:
                zip_ref.extractall()
            weights_file_path = 'detail_classify.pt'
            self.detail_classify_yolo_model = torch.hub.load(yolo_dir, 'custom', weights_file_path, source='local')

            base_url = 'https://cloud-api.yandex.net/v1/disk/public/resources/download?'
            public_key = rama_detect  # Сюда вписываете вашу ссылку
            # Получаем загрузочную ссылку
            final_url = base_url + urlencode(dict(public_key=public_key))
            response = requests.get(final_url)
            download_url = response.json()['href']
            # Загружаем файл и сохраняем его
            download_response = requests.get(download_url)
            zip_path = 'rama_detect.zip'
            # print(download_response.content)
            with open(zip_path, 'wb') as f:
                f.write(download_response.content)

            with zipfile.ZipFile(zip_path, 'r') as zip_ref:
                zip_ref.extractall()
            weights_file_path = 'rama_detect.pt'
            self.rama_detect_model = torch.hub.load(yolo_dir, 'custom', weights_file_path, source='local')

            base_url = 'https://cloud-api.yandex.net/v1/disk/public/resources/download?'
            public_key = balka_detect  # Сюда вписываете вашу ссылку
            # Получаем загрузочную ссылку
            final_url = base_url + urlencode(dict(public_key=public_key))
            response = requests.get(final_url)
            download_url = response.json()['href']
            # Загружаем файл и сохраняем его
            download_response = requests.get(download_url)
            zip_path = 'balka_detect.zip'
            # print(download_response.content)
            with open(zip_path, 'wb') as f:
                f.write(download_response.content)

            with zipfile.ZipFile(zip_path, 'r') as zip_ref:
                zip_ref.extractall()
            weights_file_path = 'balka_detect.pt'
            self.balka_detect_model = torch.hub.load(yolo_dir, 'custom', weights_file_path, source='local')

            base_url = 'https://cloud-api.yandex.net/v1/disk/public/resources/download?'
            public_key = vagon_detect  # Сюда вписываете вашу ссылку
            # Получаем загрузочную ссылку
            final_url = base_url + urlencode(dict(public_key=public_key))
            response = requests.get(final_url)
            download_url = response.json()['href']
            # Загружаем файл и сохраняем его
            download_response = requests.get(download_url)
            zip_path = 'vagon_number_detect.zip'
            # print(download_response.content)
            with open(zip_path, 'wb') as f:
                f.write(download_response.content)

            with zipfile.ZipFile(zip_path, 'r') as zip_ref:
                zip_ref.extractall()
            weights_file_path = 'vagon_number_detect.pt'
            self.vagon_number_detect_model = torch.hub.load(yolo_dir, 'custom', weights_file_path, source='local')






    def classify(self, image_initial):
        """classify(img:openCV frame):Class_im - classify openCV img with CNN, returns Class_im"""
        hash_object = hashlib.md5(bytes(str(datetime.now()), 'utf-8'))
        hash_str = hash_object.hexdigest()
        initial_image_path = 'initial_image' + hash_str + '.jpg'
        cv2.imwrite(initial_image_path, image_initial)

        img = cv2.imread(initial_image_path)
        results = self.detail_classify_yolo_model([initial_image_path], size=512)
        json_res = results.pandas().xyxy[0].to_json(orient="records")
        res2 = json.loads(json_res)
        if len(res2) == 0:
            conf = [0.0, 0.0, 0.0]
            results_balka = self.balka_detect_model([initial_image_path])
            json_res_balka = results_balka.pandas().xyxy[0].to_json(orient="records")
            res2_balka = json.loads(json_res_balka)
            if len(res2_balka) > 0:
                conf[0] = res2_balka[0]['confidence']
            results_rama = self.rama_detect_model([initial_image_path])
            json_res_rama = results_rama.pandas().xyxy[0].to_json(orient="records")
            res2_rama = json.loads(json_res_rama)
            if len(res2_rama) > 0:
                conf[1] = res2_rama[0]['confidence']
            results_vagon = self.vagon_number_detect_model([initial_image_path])
            json_res_vagon = results_vagon.pandas().xyxy[0].to_json(orient="records")
            res2_vagon = json.loads(json_res_vagon)
            if len(res2_vagon) > 0:
                conf[2] = res2_vagon[0]['confidence']
            if (conf[0] == 0.0) & (conf[1] == 0.0) & (conf[2] == 0.0):
                img_grey = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
                img_grey_size = cv2.resize(img_grey, (512, 512))
                data = np.array(img_grey_size, dtype="float") / 255.0
                data = data.reshape((1, 512, 512))
                res = self.detail_classify_CNN_model.predict(data)
                res_list = res[0].tolist()
                res_index = res_list.index(max(res_list))
                conf_res = res_list[res_index]
            else:
                res_index = conf.index(max(conf))
                conf_res = max(conf)
        else:
            res_index = res2[0]['class']
            conf_res = res2[0]['confidence']
        class_detail = Class_detail(res_index)
        os.remove(initial_image_path)
        return Class_detail_result(class_detail, round(conf_res, 2))



from danila.danila_balka.danila_balka_text_recognize.danila_balka_text_recognize_init_1 import \
    Danila_balka_text_recognize_init_1
from danila.danila_balka.danila_balka_text_recognize.danila_balka_text_recognize_init_2 import \
    Danila_balka_text_recognize_init_2
from danila.danila_balka.danila_balka_text_recognize.danila_balka_text_recognize_init_3 import \
    Danila_balka_text_recognize_init_3
from danila.danila_balka.danila_balka_text_recognize.danila_balka_text_recognize_init_4 import \
    Danila_balka_text_recognize_init_4
from danila.danila_balka.danila_balka_text_recognize.danila_balka_text_recognize_init_5 import \
    Danila_balka_text_recognize_init_5


class Danila_balka_text_recognize_init:
    def __init__(self, yolov5_dir, balka_text_recognize_version):
        if balka_text_recognize_version == 1:
            self.danila_balka_text_recognize_init = Danila_balka_text_recognize_init_1(yolov5_dir=yolov5_dir)
        elif balka_text_recognize_version == 2:
            self.danila_balka_text_recognize_init = Danila_balka_text_recognize_init_2(yolov5_dir=yolov5_dir)
        elif balka_text_recognize_version == 3:
            self.danila_balka_text_recognize_init = Danila_balka_text_recognize_init_3(yolov5_dir=yolov5_dir)
        elif balka_text_recognize_version == 4:
            self.danila_balka_text_recognize_init = Danila_balka_text_recognize_init_4(yolov5_dir=yolov5_dir)
        elif balka_text_recognize_version == 5:
            self.danila_balka_text_recognize_init = Danila_balka_text_recognize_init_5(yolov5_dir=yolov5_dir)

    def balka_text_recognize(self, balka_prod, img_cut, image_text_areas):
        return self.danila_balka_text_recognize_init.balka_text_recognize(balka_prod, img_cut, image_text_areas)





class Danila_balka_text_recognize_params:
    def __init__(self, balka_text_recognize_version):
        if balka_text_recognize_version < 40:
            year_post_num = balka_text_recognize_version // 20
            if year_post_num == 0:
                self.year_post = False
            else:
                self.year_post = True
            balka_text_recognize_version_20 = balka_text_recognize_version % 20
            prod_redone_num = balka_text_recognize_version_20 // 10
            self.prod_redone = (prod_redone_num == 1)
            balka_text_recognize_version_10 = balka_text_recognize_version_20 % 10
            self.balka_text_recognize_model_version = balka_text_recognize_version_10
            if balka_text_recognize_version_10 > 5:
                raise ValueError('rama_text_recognize_version - incorrect')
        else:
            raise ValueError('rama_text_recognize_version - incorrect')


ALTAI_NUMBER_LENGTH, ALTAI_NUMBER_HEIGHT, ALTAI_NUMBER_WIDTH = 5, 96, 96
ALTAI_PROD_LENGTH, ALTAI_PROD_HEIGHT, ALTAI_PROD_WIDTH = 4, 96, 96
ALTAI_YEAR_LENGTH, ALTAI_YEAR_HEIGHT, ALTAI_YEAR_WIDTH = 2, 64, 64
BEGICKAYA_NUMBER_LENGTH, BEGICKAYA_NUMBER_HEIGHT, BEGICKAYA_NUMBER_WIDTH = 5, 64, 64
BEGICKAYA_PROD_LENGTH, BEGICKAYA_PROD_HEIGHT, BEGICKAYA_PROD_WIDTH = 2, 64, 64
BEGICKAYA_YEAR_LENGTH, BEGICKAYA_YEAR_HEIGHT, BEGICKAYA_YEAR_WIDTH = 2, 64, 64
PROMLIT_NUMBER_LENGTH, PROMLIT_NUMBER_HEIGHT, PROMLIT_NUMBER_WIDTH = 5, 192, 192
PROMLIT_PROD_LENGTH, PROMLIT_PROD_HEIGHT, PROMLIT_PROD_WIDTH = 2, 128, 128
PROMLIT_YEAR_LENGTH, PROMLIT_YEAR_HEIGHT, PROMLIT_YEAR_WIDTH = 2, 32, 32
RUZHIMMASH_NUMBER_LENGTH, RUZHIMMASH_NUMBER_HEIGHT, RUZHIMMASH_NUMBER_WIDTH = 5, 128, 128
RUZHIMMASH_PROD_LENGTH, RUZHIMMASH_PROD_HEIGHT, RUZHIMMASH_PROD_WIDTH = 4, 96, 96
RUZHIMMASH_YEAR_LENGTH, RUZHIMMASH_YEAR_HEIGHT, RUZHIMMASH_YEAR_WIDTH = 2, 64, 64
TIHVIN_NUMBER_LENGTH, TIHVIN_NUMBER_HEIGHT, TIHVIN_NUMBER_WIDTH = 5, 128, 128
TIHVIN_PROD_LENGTH, TIHVIN_PROD_HEIGHT, TIHVIN_PROD_WIDTH = 4, 64, 64
TIHVIN_YEAR_LENGTH, TIHVIN_YEAR_HEIGHT, TIHVIN_YEAR_WIDTH = 2, 64, 64


class Danila_balka_text_recognize_year_post:
    def __init__(self, danila_balka_text_recognize):
        self.danila_balka_text_recognize = danila_balka_text_recognize

    def balka_text_recognize(self, balka_prod, img_cut, image_text_areas):
        res_labels = self.danila_balka_text_recognize.balka_text_recognize(balka_prod, img_cut, image_text_areas)
        (year_text, year_conf) = res_labels['year']
        if (len(year_text) == 2) and (int(year_text) < 25):
            res_labels['year'] = (year_text, year_conf)
        else:
            res_labels['year'] = ('24', 0.25)
        return res_labels



class Danila_balka_text_detect_params:
    def __init__(self, balka_detect_version, balka_text_detect_version):
        self.balka_detect_version = balka_detect_version
        self.balka_text_detect_version = balka_text_detect_version


import hashlib
import os
from datetime import datetime

import cv2

from data.neuro.Rama_detect_class import Rama_detect_class
from data.neuro.Rama_text_detect_class import Rama_text_detect_class
from data.neuro.local_models import *
from data.neuro.models import *
from data.result import Rama_prod


class Danila_rama_text_detect_base:
    def __init__(self, local, yolov5_dir, rama_detect_version, rama_text_detect_version):

        if local:
            if (rama_detect_version == 1) & (rama_text_detect_version == 1):

                self.rama_detect_objects = {
                     Rama_prod.Rama_Prod.altai: None,
                     Rama_prod.Rama_Prod.balakovo: None,
                     Rama_prod.Rama_Prod.begickaya: None,
                     Rama_prod.Rama_Prod.promlit: None,
                     Rama_prod.Rama_Prod.ruzhimmash: None,
                     Rama_prod.Rama_Prod.tihvin: None,
                     Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_detect_class(local, LOCAL_RAMA_ALTAI_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_detect_class(local, LOCAL_RAMA_BALAKOVO_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_detect_class(local, LOCAL_RAMA_BEGICKAYA_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_detect_class(local, LOCAL_RAMA_PROMLIT_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_detect_class(local, LOCAL_RAMA_RUZHIMMASH_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_detect_class(local, LOCAL_RAMA_TIHVIN_DETECT_MODEL_ADDRESS,
                                                                                          yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_detect_class(
                    local, LOCAL_RAMA_URALVAGON_DETECT_MODEL_ADDRESS, yolov5_dir)

                self.rama_text_detect_objects = {
                    Rama_prod.Rama_Prod.altai: None,
                    Rama_prod.Rama_Prod.balakovo: None,
                    Rama_prod.Rama_Prod.begickaya: None,
                    Rama_prod.Rama_Prod.promlit: None,
                    Rama_prod.Rama_Prod.ruzhimmash: None,
                    Rama_prod.Rama_Prod.tihvin: None,
                    Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_text_detect_class(local, LOCAL_RAMA_ALTAI_TEXT_DETECT_MODEL_ADDRESS,
                                                                                        yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_text_detect_class(local, LOCAL_RAMA_BALAKOVO_TEXT_DETECT_MODEL_ADDRESS,
                                                                                           yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_text_detect_class(local, LOCAL_RAMA_BEGICKAYA_TEXT_DETECT_MODEL_ADDRESS,
                                                                                            yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_text_detect_class(local, LOCAL_RAMA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS,
                                                                                          yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_text_detect_class(
                    local, LOCAL_RAMA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_text_detect_class(local, LOCAL_RAMA_TIHVIN_TEXT_DETECT_MODEL_ADDRESS,
                                                                                         yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_text_detect_class(
                    local, LOCAL_RAMA_URALVAGON_TEXT_DETECT_MODEL_ADDRESS, yolov5_dir)
            elif (rama_detect_version == 2) & (rama_text_detect_version == 2):

                self.rama_detect_objects = {
                     Rama_prod.Rama_Prod.altai: None,
                     Rama_prod.Rama_Prod.balakovo: None,
                     Rama_prod.Rama_Prod.begickaya: None,
                     Rama_prod.Rama_Prod.promlit: None,
                     Rama_prod.Rama_Prod.ruzhimmash: None,
                     Rama_prod.Rama_Prod.tihvin: None,
                     Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_detect_class(local, LOCAL_RAMA_ALTAI_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_detect_class(local, LOCAL_RAMA_BALAKOVO_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_detect_class(local, LOCAL_RAMA_BEGICKAYA_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_detect_class(local, LOCAL_RAMA_PROMLIT_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_detect_class(local, LOCAL_RAMA_RUZHIMMASH_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_detect_class(local, LOCAL_RAMA_TIHVIN_DETECT_MODEL_ADDRESS,
                                                                                          yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_detect_class(
                    local, LOCAL_RAMA_URALVAGON_DETECT_MODEL_ADDRESS, yolov5_dir)

                self.rama_text_detect_objects = {
                    Rama_prod.Rama_Prod.altai: None,
                    Rama_prod.Rama_Prod.balakovo: None,
                    Rama_prod.Rama_Prod.begickaya: None,
                    Rama_prod.Rama_Prod.promlit: None,
                    Rama_prod.Rama_Prod.ruzhimmash: None,
                    Rama_prod.Rama_Prod.tihvin: None,
                    Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_text_detect_class(local, LOCAL_RAMA_ALTAI_TEXT_DETECT_MODEL_ADDRESS,
                                                                                        yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_text_detect_class(local, LOCAL_RAMA_BALAKOVO_TEXT_DETECT_MODEL_ADDRESS,
                                                                                           yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_text_detect_class(local, LOCAL_RAMA_BEGICKAYA_TEXT_DETECT_MODEL_ADDRESS,
                                                                                            yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_text_detect_class(local, LOCAL_RAMA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS,
                                                                                          yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_text_detect_class(
                    local, LOCAL_RAMA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_text_detect_class(local, LOCAL_RAMA_TIHVIN_TEXT_DETECT_MODEL_ADDRESS,
                                                                                         yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_text_detect_class(
                    local, LOCAL_RAMA_URALVAGON_TEXT_DETECT_MODEL_ADDRESS, yolov5_dir)
            elif (rama_detect_version == 3) & (rama_text_detect_version == 3):

                self.rama_detect_objects = {
                     Rama_prod.Rama_Prod.altai: None,
                     Rama_prod.Rama_Prod.balakovo: None,
                     Rama_prod.Rama_Prod.begickaya: None,
                     Rama_prod.Rama_Prod.promlit: None,
                     Rama_prod.Rama_Prod.ruzhimmash: None,
                     Rama_prod.Rama_Prod.tihvin: None,
                     Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_detect_class(local, LOCAL_RAMA_ALTAI_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_detect_class(local, LOCAL_RAMA_BALAKOVO_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_detect_class(local, LOCAL_RAMA_BEGICKAYA_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_detect_class(local, LOCAL_RAMA_PROMLIT_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_detect_class(local, LOCAL_RAMA_RUZHIMMASH_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_detect_class(local, LOCAL_RAMA_TIHVIN_DETECT_MODEL_ADDRESS,
                                                                                          yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_detect_class(
                    local, LOCAL_RAMA_URALVAGON_DETECT_MODEL_ADDRESS, yolov5_dir)

                self.rama_text_detect_objects = {
                    Rama_prod.Rama_Prod.altai: None,
                    Rama_prod.Rama_Prod.balakovo: None,
                    Rama_prod.Rama_Prod.begickaya: None,
                    Rama_prod.Rama_Prod.promlit: None,
                    Rama_prod.Rama_Prod.ruzhimmash: None,
                    Rama_prod.Rama_Prod.tihvin: None,
                    Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_text_detect_class(local, LOCAL_RAMA_ALTAI_TEXT_DETECT_MODEL_ADDRESS_2,
                                                                                        yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_text_detect_class(local, LOCAL_RAMA_BALAKOVO_TEXT_DETECT_MODEL_ADDRESS,
                                                                                           yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_text_detect_class(local, LOCAL_RAMA_BEGICKAYA_TEXT_DETECT_MODEL_ADDRESS,
                                                                                            yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_text_detect_class(local, LOCAL_RAMA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS,
                                                                                          yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_text_detect_class(
                    local, LOCAL_RAMA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_text_detect_class(local, LOCAL_RAMA_TIHVIN_TEXT_DETECT_MODEL_ADDRESS,
                                                                                         yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_text_detect_class(
                    local, LOCAL_RAMA_URALVAGON_TEXT_DETECT_MODEL_ADDRESS, yolov5_dir)
            elif (rama_detect_version == 4) & (rama_text_detect_version == 4):

                self.rama_detect_objects = {
                     Rama_prod.Rama_Prod.altai: None,
                     Rama_prod.Rama_Prod.balakovo: None,
                     Rama_prod.Rama_Prod.begickaya: None,
                     Rama_prod.Rama_Prod.promlit: None,
                     Rama_prod.Rama_Prod.ruzhimmash: None,
                     Rama_prod.Rama_Prod.tihvin: None,
                     Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_detect_class(local, LOCAL_RAMA_ALTAI_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_detect_class(local, LOCAL_RAMA_BALAKOVO_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_detect_class(local, LOCAL_RAMA_BEGICKAYA_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_detect_class(local, LOCAL_RAMA_PROMLIT_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_detect_class(local, LOCAL_RAMA_RUZHIMMASH_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_detect_class(local, LOCAL_RAMA_TIHVIN_DETECT_MODEL_ADDRESS,
                                                                                          yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_detect_class(
                    local, LOCAL_RAMA_URALVAGON_DETECT_MODEL_ADDRESS, yolov5_dir)

                self.rama_text_detect_objects = {
                    Rama_prod.Rama_Prod.altai: None,
                    Rama_prod.Rama_Prod.balakovo: None,
                    Rama_prod.Rama_Prod.begickaya: None,
                    Rama_prod.Rama_Prod.promlit: None,
                    Rama_prod.Rama_Prod.ruzhimmash: None,
                    Rama_prod.Rama_Prod.tihvin: None,
                    Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_text_detect_class(local, LOCAL_RAMA_ALTAI_TEXT_DETECT_MODEL_ADDRESS_2,
                                                                                        yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_text_detect_class(local, LOCAL_RAMA_BALAKOVO_TEXT_DETECT_MODEL_ADDRESS,
                                                                                           yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_text_detect_class(local, LOCAL_RAMA_BEGICKAYA_TEXT_DETECT_MODEL_ADDRESS,
                                                                                            yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_text_detect_class(local, LOCAL_RAMA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS_2,
                                                                                          yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_text_detect_class(
                    local, LOCAL_RAMA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_text_detect_class(local, LOCAL_RAMA_TIHVIN_TEXT_DETECT_MODEL_ADDRESS,
                                                                                         yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_text_detect_class(
                    local, LOCAL_RAMA_URALVAGON_TEXT_DETECT_MODEL_ADDRESS, yolov5_dir)
            elif (rama_detect_version == 5) & (rama_text_detect_version == 4):

                self.rama_detect_objects = {
                     Rama_prod.Rama_Prod.altai: None,
                     Rama_prod.Rama_Prod.balakovo: None,
                     Rama_prod.Rama_Prod.begickaya: None,
                     Rama_prod.Rama_Prod.promlit: None,
                     Rama_prod.Rama_Prod.ruzhimmash: None,
                     Rama_prod.Rama_Prod.tihvin: None,
                     Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_detect_class(local, LOCAL_RAMA_ALTAI_DETECT_MODEL_ADDRESS_2, yolov5_dir, True)

                print('reading and loading - RAMA_BALAKOVO_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_detect_class(local, LOCAL_RAMA_BALAKOVO_DETECT_MODEL_ADDRESS, yolov5_dir, True)

                print('reading and loading - RAMA_BEGICKAYA_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_detect_class(local, LOCAL_RAMA_BEGICKAYA_DETECT_MODEL_ADDRESS, yolov5_dir, True)

                print('reading and loading - RAMA_PROMLIT_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_detect_class(local, LOCAL_RAMA_PROMLIT_DETECT_MODEL_ADDRESS_2, yolov5_dir, True)

                print('reading and loading - RAMA_RUZHIMMASH_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_detect_class(local, LOCAL_RAMA_RUZHIMMASH_DETECT_MODEL_ADDRESS_2, yolov5_dir, True)

                print('reading and loading - RAMA_TIHVIN_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_detect_class(local, LOCAL_RAMA_TIHVIN_DETECT_MODEL_ADDRESS,
                                                                                          yolov5_dir, True)

                print('reading and loading - RAMA_URALVAGON_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_detect_class(
                    local, LOCAL_RAMA_URALVAGON_DETECT_MODEL_ADDRESS, yolov5_dir, True)

                self.rama_text_detect_objects = {
                    Rama_prod.Rama_Prod.altai: None,
                    Rama_prod.Rama_Prod.balakovo: None,
                    Rama_prod.Rama_Prod.begickaya: None,
                    Rama_prod.Rama_Prod.promlit: None,
                    Rama_prod.Rama_Prod.ruzhimmash: None,
                    Rama_prod.Rama_Prod.tihvin: None,
                    Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_text_detect_class(local, LOCAL_RAMA_ALTAI_TEXT_DETECT_MODEL_ADDRESS_2,
                                                                                        yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_text_detect_class(local, LOCAL_RAMA_BALAKOVO_TEXT_DETECT_MODEL_ADDRESS,
                                                                                           yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_text_detect_class(local, LOCAL_RAMA_BEGICKAYA_TEXT_DETECT_MODEL_ADDRESS,
                                                                                            yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_text_detect_class(local, LOCAL_RAMA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS_2,
                                                                                          yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_text_detect_class(
                    local, LOCAL_RAMA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_text_detect_class(local, LOCAL_RAMA_TIHVIN_TEXT_DETECT_MODEL_ADDRESS,
                                                                                         yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_text_detect_class(
                    local, LOCAL_RAMA_URALVAGON_TEXT_DETECT_MODEL_ADDRESS, yolov5_dir)
        else:
            if (rama_detect_version == 1) & (rama_text_detect_version == 1):

                self.rama_detect_objects = {
                    Rama_prod.Rama_Prod.altai: None,
                    Rama_prod.Rama_Prod.balakovo: None,
                    Rama_prod.Rama_Prod.begickaya: None,
                    Rama_prod.Rama_Prod.promlit: None,
                    Rama_prod.Rama_Prod.ruzhimmash: None,
                    Rama_prod.Rama_Prod.tihvin: None,
                    Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_detect_class(local, RAMA_ALTAI_DETECT_MODEL_ADDRESS,
                                                                                        yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_detect_class(
                    local, RAMA_BALAKOVO_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_detect_class(
                    local, RAMA_BEGICKAYA_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_detect_class(
                    local, RAMA_PROMLIT_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_detect_class(
                    local, RAMA_RUZHIMMASH_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_detect_class(
                    local, RAMA_TIHVIN_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_detect_class(
                    local, RAMA_URALVAGON_DETECT_MODEL_ADDRESS, yolov5_dir)

                self.rama_text_detect_objects = {
                    Rama_prod.Rama_Prod.altai: None,
                    Rama_prod.Rama_Prod.balakovo: None,
                    Rama_prod.Rama_Prod.begickaya: None,
                    Rama_prod.Rama_Prod.promlit: None,
                    Rama_prod.Rama_Prod.ruzhimmash: None,
                    Rama_prod.Rama_Prod.tihvin: None,
                    Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_text_detect_class(
                    local, RAMA_ALTAI_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_text_detect_class(
                    local, RAMA_BALAKOVO_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_text_detect_class(
                    local, RAMA_BEGICKAYA_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_text_detect_class(
                    local, RAMA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_text_detect_class(
                    local, RAMA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_text_detect_class(
                    local, RAMA_TIHVIN_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_text_detect_class(
                    local, RAMA_URALVAGON_TEXT_DETECT_MODEL_ADDRESS, yolov5_dir)
            elif (rama_detect_version == 2) & (rama_text_detect_version == 2):

                self.rama_detect_objects = {
                    Rama_prod.Rama_Prod.altai: None,
                    Rama_prod.Rama_Prod.balakovo: None,
                    Rama_prod.Rama_Prod.begickaya: None,
                    Rama_prod.Rama_Prod.promlit: None,
                    Rama_prod.Rama_Prod.ruzhimmash: None,
                    Rama_prod.Rama_Prod.tihvin: None,
                    Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_detect_class(local, RAMA_ALTAI_DETECT_MODEL_ADDRESS,
                                                                                        yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_detect_class(
                    local, RAMA_BALAKOVO_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_detect_class(
                    local, RAMA_BEGICKAYA_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_detect_class(
                    local, RAMA_PROMLIT_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_detect_class(
                    local, RAMA_RUZHIMMASH_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_detect_class(
                    local, RAMA_TIHVIN_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_detect_class(
                    local, RAMA_URALVAGON_DETECT_MODEL_ADDRESS, yolov5_dir)

                self.rama_text_detect_objects = {
                    Rama_prod.Rama_Prod.altai: None,
                    Rama_prod.Rama_Prod.balakovo: None,
                    Rama_prod.Rama_Prod.begickaya: None,
                    Rama_prod.Rama_Prod.promlit: None,
                    Rama_prod.Rama_Prod.ruzhimmash: None,
                    Rama_prod.Rama_Prod.tihvin: None,
                    Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_text_detect_class(
                    local, RAMA_ALTAI_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_text_detect_class(
                    local, RAMA_BALAKOVO_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_text_detect_class(
                    local, RAMA_BEGICKAYA_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_text_detect_class(
                    local, RAMA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_text_detect_class(
                    local, RAMA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_text_detect_class(
                    local, RAMA_TIHVIN_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_text_detect_class(
                    local, RAMA_URALVAGON_TEXT_DETECT_MODEL_ADDRESS, yolov5_dir)
            elif (rama_detect_version == 3) & (rama_text_detect_version == 3):

                self.rama_detect_objects = {
                    Rama_prod.Rama_Prod.altai: None,
                    Rama_prod.Rama_Prod.balakovo: None,
                    Rama_prod.Rama_Prod.begickaya: None,
                    Rama_prod.Rama_Prod.promlit: None,
                    Rama_prod.Rama_Prod.ruzhimmash: None,
                    Rama_prod.Rama_Prod.tihvin: None,
                    Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_detect_class(
                    local, RAMA_ALTAI_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_detect_class(
                    local, RAMA_BALAKOVO_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_detect_class(
                    local, RAMA_BEGICKAYA_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_detect_class(
                    local, RAMA_PROMLIT_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_detect_class(
                    local, RAMA_RUZHIMMASH_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_detect_class(
                    local, RAMA_TIHVIN_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_detect_class(
                    local, RAMA_URALVAGON_DETECT_MODEL_ADDRESS, yolov5_dir)

                self.rama_text_detect_objects = {
                    Rama_prod.Rama_Prod.altai: None,
                    Rama_prod.Rama_Prod.balakovo: None,
                    Rama_prod.Rama_Prod.begickaya: None,
                    Rama_prod.Rama_Prod.promlit: None,
                    Rama_prod.Rama_Prod.ruzhimmash: None,
                    Rama_prod.Rama_Prod.tihvin: None,
                    Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_text_detect_class(
                    local, RAMA_ALTAI_TEXT_DETECT_MODEL_ADDRESS_2,
                    yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_text_detect_class(
                    local, RAMA_BALAKOVO_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_text_detect_class(
                    local, RAMA_BEGICKAYA_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_text_detect_class(
                    local, RAMA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_text_detect_class(
                    local, RAMA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_text_detect_class(
                    local, RAMA_TIHVIN_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_text_detect_class(
                    local, RAMA_URALVAGON_TEXT_DETECT_MODEL_ADDRESS, yolov5_dir)
            elif (rama_detect_version == 4) & (rama_text_detect_version == 4):

                self.rama_detect_objects = {
                    Rama_prod.Rama_Prod.altai: None,
                    Rama_prod.Rama_Prod.balakovo: None,
                    Rama_prod.Rama_Prod.begickaya: None,
                    Rama_prod.Rama_Prod.promlit: None,
                    Rama_prod.Rama_Prod.ruzhimmash: None,
                    Rama_prod.Rama_Prod.tihvin: None,
                    Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_detect_class(
                    local, RAMA_ALTAI_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_detect_class(
                    local, RAMA_BALAKOVO_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_detect_class(
                    local, RAMA_BEGICKAYA_DETECT_MODEL_ADDRESS, yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_detect_class(
                    local, RAMA_PROMLIT_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_detect_class(
                    local, RAMA_RUZHIMMASH_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_detect_class(
                    local, RAMA_TIHVIN_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_detect_class(
                    local, RAMA_URALVAGON_DETECT_MODEL_ADDRESS, yolov5_dir)

                self.rama_text_detect_objects = {
                    Rama_prod.Rama_Prod.altai: None,
                    Rama_prod.Rama_Prod.balakovo: None,
                    Rama_prod.Rama_Prod.begickaya: None,
                    Rama_prod.Rama_Prod.promlit: None,
                    Rama_prod.Rama_Prod.ruzhimmash: None,
                    Rama_prod.Rama_Prod.tihvin: None,
                    Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_text_detect_class(
                    local, RAMA_ALTAI_TEXT_DETECT_MODEL_ADDRESS_2,
                    yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_text_detect_class(
                    local, RAMA_BALAKOVO_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_text_detect_class(
                    local, RAMA_BEGICKAYA_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_text_detect_class(
                    local, RAMA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS_2,
                    yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_text_detect_class(
                    local, RAMA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_text_detect_class(
                    local, RAMA_TIHVIN_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_text_detect_class(
                    local, RAMA_URALVAGON_TEXT_DETECT_MODEL_ADDRESS, yolov5_dir)
            elif (rama_detect_version == 5) & (rama_text_detect_version == 4):

                self.rama_detect_objects = {
                    Rama_prod.Rama_Prod.altai: None,
                    Rama_prod.Rama_Prod.balakovo: None,
                    Rama_prod.Rama_Prod.begickaya: None,
                    Rama_prod.Rama_Prod.promlit: None,
                    Rama_prod.Rama_Prod.ruzhimmash: None,
                    Rama_prod.Rama_Prod.tihvin: None,
                    Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_detect_class(
                    local, RAMA_ALTAI_DETECT_MODEL_ADDRESS_2, yolov5_dir, True)

                print('reading and loading - RAMA_BALAKOVO_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_detect_class(
                    local, RAMA_BALAKOVO_DETECT_MODEL_ADDRESS, yolov5_dir, True)

                print('reading and loading - RAMA_BEGICKAYA_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_detect_class(
                    local, RAMA_BEGICKAYA_DETECT_MODEL_ADDRESS, yolov5_dir, True)

                print('reading and loading - RAMA_PROMLIT_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_detect_class(
                    local, RAMA_PROMLIT_DETECT_MODEL_ADDRESS_2, yolov5_dir, True)

                print('reading and loading - RAMA_RUZHIMMASH_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_detect_class(
                    local, RAMA_RUZHIMMASH_DETECT_MODEL_ADDRESS_2, yolov5_dir, True)

                print('reading and loading - RAMA_TIHVIN_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_detect_class(
                    local, RAMA_TIHVIN_DETECT_MODEL_ADDRESS,
                    yolov5_dir, True)

                print('reading and loading - RAMA_URALVAGON_DETECT_MODEL')
                self.rama_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_detect_class(
                    local, RAMA_URALVAGON_DETECT_MODEL_ADDRESS, yolov5_dir, True)

                self.rama_text_detect_objects = {
                    Rama_prod.Rama_Prod.altai: None,
                    Rama_prod.Rama_Prod.balakovo: None,
                    Rama_prod.Rama_Prod.begickaya: None,
                    Rama_prod.Rama_Prod.promlit: None,
                    Rama_prod.Rama_Prod.ruzhimmash: None,
                    Rama_prod.Rama_Prod.tihvin: None,
                    Rama_prod.Rama_Prod.uralvagon: None
                }

                print('reading and loading - RAMA_ALTAI_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.altai] = Rama_text_detect_class(
                    local, RAMA_ALTAI_TEXT_DETECT_MODEL_ADDRESS_2,
                    yolov5_dir)

                print('reading and loading - RAMA_BALAKOVO_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.balakovo] = Rama_text_detect_class(
                    local, RAMA_BALAKOVO_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_BEGICKAYA_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.begickaya] = Rama_text_detect_class(
                    local, RAMA_BEGICKAYA_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_PROMLIT_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.promlit] = Rama_text_detect_class(
                    local, RAMA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS_2,
                    yolov5_dir)

                print('reading and loading - RAMA_RUZHIMMASH_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.ruzhimmash] = Rama_text_detect_class(
                    local, RAMA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS_2, yolov5_dir)

                print('reading and loading - RAMA_TIHVIN_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.tihvin] = Rama_text_detect_class(
                    local, RAMA_TIHVIN_TEXT_DETECT_MODEL_ADDRESS,
                    yolov5_dir)

                print('reading and loading - RAMA_URALVAGON_TEXT_DETECT_MODEL')
                self.rama_text_detect_objects[Rama_prod.Rama_Prod.uralvagon] = Rama_text_detect_class(
                    local, RAMA_URALVAGON_TEXT_DETECT_MODEL_ADDRESS, yolov5_dir)

    def rama_text_detect(self, img, rama_prod):
        hash_object = hashlib.md5(bytes(str(datetime.now()), 'utf-8'))
        hash_str = hash_object.hexdigest()
        initial_image_path = 'initial_image' + hash_str + '.jpg'
        cv2.imwrite(initial_image_path, img)
        rect = self.rama_detect_objects[rama_prod].rama_detect(initial_image_path)
        if rect is None:
            image_text_areas = self.rama_text_detect_objects[rama_prod].text_detect(initial_image_path)
            image_drawn_text_areas = self.rama_text_detect_objects[rama_prod].draw_text_areas_in_opencv(
                image_text_areas, img)
            os.remove(initial_image_path)
            return image_drawn_text_areas
        img_cut = img[rect.ymin:rect.ymax, rect.xmin:rect.xmax]
        hash_object = hashlib.md5(bytes(str(datetime.now()), 'utf-8'))
        hash_str = hash_object.hexdigest()
        img_cut_path = 'cut_img' + hash_str + '.jpg'
        cv2.imwrite(img_cut_path, img_cut)
        image_text_areas = self.rama_text_detect_objects[rama_prod].text_detect(img_cut_path)
        image_drawn_text_areas = self.rama_text_detect_objects[rama_prod].draw_text_areas_in_opencv(
            image_text_areas, img_cut)
        os.remove(initial_image_path)
        os.remove(img_cut_path)
        return image_drawn_text_areas

    def rama_text_detect_cuts(self, img, rama_prod):
        hash_object = hashlib.md5(bytes(str(datetime.now()), 'utf-8'))
        hash_str = hash_object.hexdigest()
        initial_image_path = 'initial_image' + hash_str + '.jpg'
        cv2.imwrite(initial_image_path, img)
        rect = self.rama_detect_objects[rama_prod].rama_detect(initial_image_path)
        if rect is None:
            image_text_areas = self.rama_text_detect_objects[rama_prod].text_detect(initial_image_path)
            os.remove(initial_image_path)
            return img, image_text_areas
        img_cut = img[rect.ymin:rect.ymax, rect.xmin:rect.xmax]
        hash_object = hashlib.md5(bytes(str(datetime.now()), 'utf-8'))
        hash_str = hash_object.hexdigest()
        img_cut_path = 'cut_img' + hash_str + '.jpg'
        cv2.imwrite(img_cut_path, img_cut)
        image_text_areas = self.rama_text_detect_objects[rama_prod].text_detect(img_cut_path)
        os.remove(initial_image_path)
        os.remove(img_cut_path)
        return img_cut, image_text_areas


from danila.danila_rama.danila_rama_text_recognize.danila_rama_text_recognize_model_5 import \
    Danila_rama_text_recognize_model_5
from danila.danila_rama.danila_rama_text_recognize.danila_rama_text_recognize_work import Danila_rama_text_recognize_work
from data.result import Rama_prod



class Danila_rama_text_recognize_init_7:
    def __init__(self, yolov5_dir):
        danila_rama_text_recognize_model = Danila_rama_text_recognize_model_5()
        model = danila_rama_text_recognize_model.get_model(yolov5_dir)
        self.prod_models = {}
        for rama_prod in Rama_prod.Rama_Prod:
            self.prod_models[rama_prod] = Danila_rama_text_recognize_work(
                text_recognize_model=model,
                prod_coefficients=danila_rama_text_recognize_model.get_prod_coefficients(rama_prod)
            )

    def rama_text_recognize(self, rama_prod, img_cut, image_text_areas):
        return self.prod_models[rama_prod].rama_text_recognize(img_cut, image_text_areas)

    def get_number_length(self, rama_prod):
        return self.prod_models[rama_prod].prod_coefficients.number_coefficients.length



from danila.danila_balka.danila_balka_text_recognize.danila_balka_text_recognize_init import \
    Danila_balka_text_recognize_init
from danila.danila_balka.danila_balka_text_recognize.danila_balka_text_recognize_prod_redone import \
    Danila_balka_text_recognize_prod_redone
from danila.danila_balka.danila_balka_text_recognize.danila_balka_text_recognize_year_post import \
    Danila_balka_text_recognize_year_post


class Danila_balka_text_recognize:
    def __init__(self, yolov5_dir, danila_balka_text_recognize_params):
        danila_balka_text_recognize = Danila_balka_text_recognize_init(
            yolov5_dir=yolov5_dir,
            balka_text_recognize_version=danila_balka_text_recognize_params.balka_text_recognize_model_version
        )
        if danila_balka_text_recognize_params.prod_redone:
            danila_balka_text_recognize = Danila_balka_text_recognize_prod_redone(danila_balka_text_recognize)
        if danila_balka_text_recognize_params.year_post:
            danila_balka_text_recognize = Danila_balka_text_recognize_year_post(danila_balka_text_recognize)
        self.danila_balka_text_recognize = danila_balka_text_recognize

    def balka_text_recognize(self, balka_prod, img_cuts, img_text_areas_2_balkas):
        return self.danila_balka_text_recognize.balka_text_recognize(balka_prod,img_cuts,img_text_areas_2_balkas)


class Danila_rama_text_recognize_params:
    def __init__(self, rama_text_recognize_version):
        if (rama_text_recognize_version < 80):
            year_post_num = rama_text_recognize_version // 40
            if year_post_num == 0:
                self.year_post = False
            else:
                self.year_post = True
            rama_text_recognize_version_40 = rama_text_recognize_version % 40
            number_shift_num = rama_text_recognize_version_40 // 20
            self.number_shift = (number_shift_num == 1)
            rama_text_recognize_version_20 = rama_text_recognize_version_40 % 20
            prod_redone_num = rama_text_recognize_version_20 // 10
            self.prod_redone = (prod_redone_num == 1)
            rama_text_recognize_version_10 = rama_text_recognize_version_20 % 10
            self.rama_text_recognize_model_version = rama_text_recognize_version_10
            if rama_text_recognize_version_10 > 7:
                raise ValueError('rama_text_recognize_version - incorrect')
        else:
            raise ValueError('rama_text_recognize_version - incorrect')







from danila.danila_rama.danila_rama_classify.danila_rama_classify import Danila_rama_classify
from danila.danila_rama.danila_rama_text_detect.danila_rama_text_detect import Danila_rama_text_detect
from danila.danila_rama.danila_rama_text_recognize.danila_rama_text_recognize import Danila_rama_text_recognize
from data.neuro.prods import RAMA_PRODS
from data.result.Rama_prod import Rama_Prod
from data.result.Text_cut_recognize_result import Text_cut_recognize_result
from data.result.Text_recognize_result import Text_recognize_result


class Danila_rama_redone:
    def __init__(self, local, yolov5_dir, danila_rama_params):
        self.danila_rama_params = danila_rama_params
        self.danila_rama_classify = Danila_rama_classify(local, yolov5_dir, self.danila_rama_params.danila_rama_classify_params)
        self.danila_rama_text_detect = Danila_rama_text_detect(local, yolov5_dir, self.danila_rama_params.danila_rama_text_detect_params)
        self.danila_rama_text_recognize = Danila_rama_text_recognize(yolov5_dir, self.danila_rama_params.danila_rama_text_recognize_params)

    def rama_classify(self,img, detail):
        rama_prod_conf = self.danila_rama_classify.rama_classify(img)
        if detail is None:
            detail_prod = Text_cut_recognize_result('rama', 1)
            det = Text_recognize_result(detail_prod)
        else:
            det = detail
        if rama_prod_conf.rama_prod != Rama_Prod.no_rama:
            text_prod = RAMA_PRODS[rama_prod_conf.rama_prod]
            det.prod = Text_cut_recognize_result(text_prod, rama_prod_conf.conf)
        return det

    def rama_text_detect(self, img):
        rama_prod_conf = self.danila_rama_classify.rama_classify(img)
        result_img = img
        if rama_prod_conf.rama_prod != Rama_Prod.no_rama:
            result_img = self.danila_rama_text_detect.rama_text_detect(img, rama_prod_conf.rama_prod)
        return result_img

    def rama_text_recognize(self, img, detail):
        rama_prod_conf = self.danila_rama_classify.rama_classify(img)
        if detail is None:
            detail_prod = Text_cut_recognize_result('rama', 1)
            det = Text_recognize_result(detail_prod)
        else:
            det = detail
        if rama_prod_conf.rama_prod != Rama_Prod.no_rama:
            text_prod = RAMA_PRODS[rama_prod_conf.rama_prod]
            det.prod = Text_cut_recognize_result(text_prod, rama_prod_conf.conf)
            img_cut, img_text_areas = self.danila_rama_text_detect.rama_rext_detect_cuts(img, rama_prod_conf.rama_prod)

            res_labels = self.danila_rama_text_recognize.rama_text_recognize(rama_prod_conf.rama_prod, img_cut, img_text_areas)
            res_labels_prod_text, res_labels_prod_conf = res_labels['prod']
            if res_labels_prod_text != text_prod:
                if res_labels_prod_text == '1923':
                    text_prod = RAMA_PRODS[rama_prod_conf.rama_prod]
                    det.prod = Text_cut_recognize_result(res_labels_prod_text, rama_prod_conf.conf)
                    img_cut, img_text_areas = self.danila_rama_text_detect.rama_rext_detect_cuts(img,
                                                                                                 Rama_Prod.altai)
                    res_labels = self.danila_rama_text_recognize.rama_text_recognize(Rama_Prod.altai, img_cut,
                                                                                     img_text_areas)
                elif res_labels_prod_text == '1487':
                    text_prod = RAMA_PRODS[rama_prod_conf.rama_prod]
                    det.prod = Text_cut_recognize_result(res_labels_prod_text, rama_prod_conf.conf)
                    img_cut, img_text_areas = self.danila_rama_text_detect.rama_rext_detect_cuts(img,
                                                                                                 Rama_Prod.balakovo)
                    res_labels = self.danila_rama_text_recognize.rama_text_recognize(Rama_Prod.balakovo, img_cut,
                                                                                     img_text_areas)
                elif res_labels_prod_text == '12':
                    text_prod = RAMA_PRODS[rama_prod_conf.rama_prod]
                    det.prod = Text_cut_recognize_result(text_prod, rama_prod_conf.conf)
                    img_cut, img_text_areas = self.danila_rama_text_detect.rama_rext_detect_cuts(img,
                                                                                                 Rama_Prod.begickaya)
                    res_labels = self.danila_rama_text_recognize.rama_text_recognize(Rama_Prod.begickaya, img_cut,
                                                                                     img_text_areas)
                elif res_labels_prod_text == '33':
                    text_prod = RAMA_PRODS[rama_prod_conf.rama_prod]
                    det.prod = Text_cut_recognize_result(res_labels_prod_text, rama_prod_conf.conf)
                    img_cut, img_text_areas = self.danila_rama_text_detect.rama_rext_detect_cuts(img,
                                                                                                 Rama_Prod.promlit)
                    res_labels = self.danila_rama_text_recognize.rama_text_recognize(Rama_Prod.promlit, img_cut,
                                                                                     img_text_areas)
                elif res_labels_prod_text == '1275':
                    text_prod = RAMA_PRODS[rama_prod_conf.rama_prod]
                    det.prod = Text_cut_recognize_result(res_labels_prod_text, rama_prod_conf.conf)
                    img_cut, img_text_areas = self.danila_rama_text_detect.rama_rext_detect_cuts(img,
                                                                                                 Rama_Prod.ruzhimmash)
                    res_labels = self.danila_rama_text_recognize.rama_text_recognize(Rama_Prod.ruzhimmash, img_cut,
                                                                                     img_text_areas)
                elif res_labels_prod_text == '1378':
                    text_prod = RAMA_PRODS[rama_prod_conf.rama_prod]
                    det.prod = Text_cut_recognize_result(res_labels_prod_text, rama_prod_conf.conf)
                    img_cut, img_text_areas = self.danila_rama_text_detect.rama_rext_detect_cuts(img,
                                                                                                 Rama_Prod.tihvin)
                    res_labels = self.danila_rama_text_recognize.rama_text_recognize(Rama_Prod.tihvin, img_cut,
                                                                                     img_text_areas)
                elif res_labels_prod_text == '5':
                    text_prod = RAMA_PRODS[rama_prod_conf.rama_prod]
                    det.prod = Text_cut_recognize_result(res_labels_prod_text, rama_prod_conf.conf)
                    img_cut, img_text_areas = self.danila_rama_text_detect.rama_rext_detect_cuts(img,
                                                                                                 Rama_Prod.uralvagon)
                    res_labels = self.danila_rama_text_recognize.rama_text_recognize(Rama_Prod.uralvagon, img_cut,
                                                                                     img_text_areas)
            res_labels_number_text, res_labels_number_conf = res_labels['number']
            det.number = Text_cut_recognize_result(res_labels_number_text, res_labels_number_conf)
            res_labels_year_text, res_labels_year_conf = res_labels['year']
            det.year = Text_cut_recognize_result(res_labels_year_text, res_labels_year_conf)
        return det


class Danila_rama_text_recognize_year_post:
    def __init__(self, danila_rama_text_recognize):
        self.danila_rama_text_recognize = danila_rama_text_recognize

    def rama_text_recognize(self, rama_prod, img_cut, image_text_areas):
        res_labels = self.danila_rama_text_recognize.rama_text_recognize(rama_prod, img_cut, image_text_areas)
        (year_text, year_conf) = res_labels['year']
        if (len(year_text) == 2) and (int(year_text) < 25):
            res_labels['year'] = (year_text, year_conf)
        else:
            res_labels['year'] = ('23', 0.25)
        return res_labels

    def get_number_length(self, rama_prod):
        return self.danila_rama_text_recognize.get_number_length(rama_prod)


from data.neuro.Balka_prod_classify_class import Balka_prod_classify_class
from data.neuro.Balka_prod_classify_class_dop_detect import Balka_prod_classify_class_dop_detect
from data.neuro.local_models import *
from data.neuro.models import *


class Danila_balka_classify_prod_dop_detect:
    def __init__(self, yolov5_dir, balka_classify_model):
        yolo_path = yolov5_dir
        if balka_classify_model == 1:
            balka_prod_classify_model_path = LOCAL_BALKA_CLASSIFY_MODEL_ADDRESS
            self.size = 640
        elif balka_classify_model == 2:
            balka_prod_classify_model_path = LOCAL_BALKA_CLASSIFY_MODEL_ADDRESS_2
            self.size = 416
            self.size_detect = 352

        print('reading and loading - BALKA_PROD_CLASSIFY_MODEL')
        self.balka_prod_classify_model = Balka_prod_classify_class_dop_detect(balka_prod_classify_model_path, LOCAL_BALKA_DETECT_MODEL_ADDRESS, yolo_path)

    def balka_classify(self, img):
        balka_prod_conf = self.balka_prod_classify_model.classify(img, self.size, self.size_detect)
        return balka_prod_conf


from danila.danila_balka.danila_balka import Danila_balka
from danila.danila_balka.danila_balka_classify.danila_balka_classify_params import Danila_balka_classify_params
from danila.danila_balka.danila_balka_params import Danila_balka_params
from danila.danila_balka.danila_balka_text_detect.danila_balka_text_detect_params import Danila_balka_text_detect_params
from danila.danila_balka.danila_balka_text_recognize.danila_balka_text_recognize_params import \
    Danila_balka_text_recognize_params
from danila.danila_detail.danila_detail import Danila_detail
from danila.danila_detail.danila_detail_params import Danila_detail_params
from danila.danila_rama.danila_rama import Danila_rama
from danila.danila_rama.danila_rama_classify.danila_rama_classify_params import Danila_rama_classify_params
from danila.danila_rama.danila_rama_params import Danila_rama_params
from danila.danila_rama.danila_rama_text_detect.danila_rama_text_detect_params import Danila_rama_text_detect_params
from danila.danila_rama.danila_rama_text_recognize.danila_rama_text_recognize_params import \
    Danila_rama_text_recognize_params
from danila.danila_vagon.danila_vagon import Danila_vagon
from danila.danila_vagon.danila_vagon_params import Danila_vagon_params
from danila.danila_vagon.danila_vagon_text_detect_params import Danila_vagon_text_detect_params
from danila.danila_vagon.danila_vagon_text_recognize_params import Danila_vagon_text_recognize_params


class Danila_v11:
    def __init__(self, local, yolov5_dir, detail_classify_version = 1,
                 rama_detect_version = 1, rama_classify_version = 1, rama_text_detect_version = 1, rama_text_recognize_version = 1,
                 vagon_text_detect_version = 1, vagon_text_recognize_version = 1,
                 balka_detect_version = 1, balka_classify_version = 1, balka_text_detect_version = 1, balka_text_recognize_version = 1):

        if detail_classify_version == 1:
            danila_detail_params = Danila_detail_params(1,2)
        elif detail_classify_version == 2:
            danila_detail_params = Danila_detail_params(2, 1)
        else:
            raise ValueError('detail_classify_version - incorrect')
        self.danila_detail = Danila_detail(local, danila_detail_params, yolo_dir=yolov5_dir)

        if (rama_classify_version > 0) & (rama_classify_version < 6):
            danila_rama_classify_params = Danila_rama_classify_params(1,rama_classify_version)
        elif (rama_classify_version > 7) & (rama_classify_version < 11):
            danila_rama_classify_params = Danila_rama_classify_params(2, rama_classify_version)

        else:
            raise ValueError('rama_classify_version - incorrect')

        if (rama_detect_version == 1) & (rama_text_detect_version == 1):
            danila_rama_text_detect_params = Danila_rama_text_detect_params(1,1)
        elif (rama_detect_version == 2) & (rama_text_detect_version == 2):
            danila_rama_text_detect_params = Danila_rama_text_detect_params(2,2)
        elif (rama_detect_version == 3) & (rama_text_detect_version == 3):
            danila_rama_text_detect_params = Danila_rama_text_detect_params(3,3)
        elif (rama_detect_version == 4) & (rama_text_detect_version == 4):
            danila_rama_text_detect_params = Danila_rama_text_detect_params(4,4)
        elif (rama_detect_version == 5) & (rama_text_detect_version == 4):
            danila_rama_text_detect_params = Danila_rama_text_detect_params(5,4)
        else:
            raise ValueError('rama_text_detect_version - incorrect')

        if (rama_text_recognize_version < 80):
            danila_rama_text_recognize_params = Danila_rama_text_recognize_params(rama_text_recognize_version)
        else:
            raise ValueError('rama_text_recognize_version - incorrect')

        danila_rama_params = Danila_rama_params(danila_rama_classify_params, danila_rama_text_detect_params, danila_rama_text_recognize_params)
        self.danila_rama = Danila_rama(local, yolov5_dir, danila_rama_params)

        if (vagon_text_detect_version == 1) | (vagon_text_detect_version == 2):
            danila_vagon_text_detect_params = Danila_vagon_text_detect_params(vagon_text_detect_version)
        else:
            raise ValueError('vagon_text_detect_version - incorrect')

        if (vagon_text_recognize_version == 1):
            danila_vagon_text_recognize_params = Danila_vagon_text_recognize_params(vagon_text_recognize_version, 320,320)
        elif (vagon_text_recognize_version == 2):
            danila_vagon_text_recognize_params = Danila_vagon_text_recognize_params(vagon_text_recognize_version, 196,196)
        elif (vagon_text_recognize_version == 3):
            danila_vagon_text_recognize_params = Danila_vagon_text_recognize_params(vagon_text_recognize_version, 196,
                                                                                    196)
        elif (vagon_text_recognize_version == 4):
            danila_vagon_text_recognize_params = Danila_vagon_text_recognize_params(vagon_text_recognize_version, 352,
                                                                                    352)
        else:
            raise ValueError('vagon_text_recognize_version - incorrect')
        danila_vagon_params = Danila_vagon_params(danila_vagon_text_detect_params, danila_vagon_text_recognize_params)
        self.danila_vagon = Danila_vagon(local, yolov5_dir, danila_vagon_params)

        if balka_classify_version in [1,2]:
            danila_balka_classify_params = Danila_balka_classify_params(1,balka_classify_version)
        elif balka_classify_version in [3,4]:
            danila_balka_classify_params = Danila_balka_classify_params(2,balka_classify_version -2)
        else:
            raise ValueError('balka_classify_version - incorrect')

        if (balka_detect_version in [1,2,3]) & (balka_text_detect_version in [1,2,3,4,5,6,7]):
            danila_balka_text_detect_params = Danila_balka_text_detect_params(balka_detect_version,balka_text_detect_version)
        else:
            raise ValueError('balka_text_detect_version - incorrect')

        if (balka_text_recognize_version < 40):
            danila_balka_text_recognize_params = Danila_balka_text_recognize_params(balka_text_recognize_version)
        else:
            raise ValueError('rama_text_recognize_version - incorrect')

        danila_balka_params = Danila_balka_params(danila_balka_classify_params, danila_balka_text_detect_params, danila_balka_text_recognize_params)
        self.danila_balka = Danila_balka(yolov5_dir, danila_balka_params)



    def detail_classify(self, img):
        detail = self.danila_detail.detail_classify(img)
        if detail.detail.text == 'rama':
            detail = self.rama_classify(img, detail)
        elif detail.detail.text == 'balka':
            detail = self.balka_classify(img, detail)
        return detail


    def detail_text_detect(self, img):
        detail = self.danila_detail.detail_classify(img)
        resul_img = img
        if detail.detail.text == 'rama':
            resul_img = self.rama_text_detect_cut(img)
        elif detail.detail.text == 'vagon':
            resul_img = self.vagon_number_detect(img)
        elif detail.detail.text == 'balka':
            resul_img = self.balka_text_detect(img)
        return resul_img

    def detail_text_recognize(self, img):
        detail = self.danila_detail.detail_classify(img)
        if detail.detail.text == 'rama':
            detail = self.rama_text_recognize(img, detail)
        elif detail.detail.text == 'vagon':
            detail = self.vagon_number_recognize(img, detail)
        elif detail.detail.text == 'balka':
            detail = self.balka_text_recognize(img, detail)
        return detail

    def rama_classify(self, img, detail = None):
        """rama_classify(Img : openCv frame): String - returns class of rama using CNN network"""
        """rama_classify uses Rama_classify_class method - classify(Img)"""
        return self.danila_rama.rama_classify(img, detail)


    # returns openCV cut rama with drawn text areas
    def rama_text_detect_cut(self, img):
        """returns openCV cut rama with drawn text areas"""
        return self.danila_rama.rama_text_detect(img)


    # returns dict {'number', 'prod', 'year'} for openCV rama img or 'no_rama'
    def rama_text_recognize(self, img, detail = None):
        """returns dict {'number', 'prod', 'year'} for openCV rama img or 'no_rama'"""
        return self.danila_rama.rama_text_recognize(img, detail)

    # returns openCV img with drawn number areas
    def vagon_number_detect(self, img):
        """returns openCV img with drawn number areas"""
        return self.danila_vagon.vagon_number_detect(
            img
        )

    def vagon_number_recognize(self, img, detail = None):
        return self.danila_vagon.vagon_number_recognize(img, detail)


    def balka_classify(self, img, detail = None):
        return self.danila_balka.balka_classify(img, detail)

    def balka_text_detect(self, img):
        return self.danila_balka.balka_text_detect(img)

    def balka_text_recognize(self, img, detail = None):
        return self.danila_balka.balka_text_recognize(img, detail)


class Danila_balka_classify_params:
    def __init__(self, balka_classify_version, balka_classify_model):
        self.balka_classify_version = balka_classify_version
        self.balka_classify_model = balka_classify_model


from danila.danila_vagon.danila_vagon_text_detect import Danila_vagon_text_detect
from danila.danila_vagon.danila_vagon_text_recognize import Danila_vagon_text_recognize
from data.result.Text_cut_recognize_result import Text_cut_recognize_result
from data.result.Text_recognize_result import Text_recognize_result


class Danila_vagon:
    def __init__(self, local, yolov5_dir, danila_vagon_params):
        self.danila_vagon_params = danila_vagon_params
        self.danila_vagon_text_detect = Danila_vagon_text_detect(local, yolov5_dir, self.danila_vagon_params.danila_vagon_text_detect_params)
        self.danila_vagon_text_recognize = Danila_vagon_text_recognize(local, yolov5_dir, self.danila_vagon_params.danila_vagon_text_recognize_params)

    def vagon_number_detect(self, img):
        self.danila_vagon_text_detect.vagon_number_detect(img)

    def vagon_number_recognize(self, img, detail = None):
        det = detail
        vagon_number_rects = self.danila_vagon_text_detect.vagon_number_detect_rects(img)
        if det is None:
            det = Text_recognize_result(Text_cut_recognize_result('vagon', 1.0))
        if len(vagon_number_rects) == 0:
            return det
        detail_number_text, detail_number_conf =  self.danila_vagon_text_recognize.vagon_number_recognize(img, vagon_number_rects)
        det.number = Text_cut_recognize_result(detail_number_text, round(detail_number_conf, 2))
        return det


from danila.danila_rama.danila_rama_text_recognize.danila_rama_text_recognize_model import *
from data.neuro.local_models import *
from data.neuro.text_recognize_yolo import Text_Recognize_yolo
from data.result import Rama_prod


class Danila_rama_text_recognize_model_1(Danila_rama_text_recognize_model):
    def get_model(self, yolo_path):
        return Text_Recognize_yolo(model_path= LOCAL_RAMA_TEXT_RECOGNIZE_MODEL_ADDRESS, yolo_path=yolo_path)
    def get_prod_coefficients(self, rama_prod):
        if rama_prod == Rama_prod.Rama_Prod.altai:
            return Prod_coefficients(
                number_coefficients= Text_coefficients(
                    length= 5, height=64, width=192
                ),
                prod_coefficients= Text_coefficients(
                    length=4, height=64, width=128
                ),
                year_coefficients=Text_coefficients(
                    length=2, height=64, width=96
                ),
            )
        elif rama_prod == Rama_prod.Rama_Prod.balakovo:
            return Prod_coefficients(
                number_coefficients=Text_coefficients(
                    length=5, height=64, width=192
                ),
                prod_coefficients=Text_coefficients(
                    length=4, height=64, width=192
                ),
                year_coefficients=Text_coefficients(
                    length=2, height=64, width=96
                ),
            )
        elif rama_prod == Rama_prod.Rama_Prod.begickaya:
            return Prod_coefficients(
                number_coefficients=Text_coefficients(
                    length=6, height=96, width=224
                ),
                prod_coefficients=Text_coefficients(
                    length=2, height=64, width=128
                ),
                year_coefficients=Text_coefficients(
                    length=2, height=64, width=96
                ),
            )
        elif rama_prod == Rama_prod.Rama_Prod.promlit:
            return Prod_coefficients(
                number_coefficients=Text_coefficients(
                    length=5, height=64, width=160
                ),
                prod_coefficients=Text_coefficients(
                    length=2, height=64, width=96
                ),
                year_coefficients=Text_coefficients(
                    length=2, height=64, width=96
                ),
            )
        elif rama_prod == Rama_prod.Rama_Prod.ruzhimmash:
            return Prod_coefficients(
                number_coefficients=Text_coefficients(
                    length=5, height=64, width=160
                ),
                prod_coefficients=Text_coefficients(
                    length=4, height=64, width=192
                ),
                year_coefficients=Text_coefficients(
                    length=2, height=64, width=96
                ),
            )
        elif rama_prod == Rama_prod.Rama_Prod.tihvin:
            return Prod_coefficients(
                number_coefficients=Text_coefficients(
                    length=5, height=64, width=160
                ),
                prod_coefficients=Text_coefficients(
                    length=4, height=64, width=224
                ),
                year_coefficients=Text_coefficients(
                    length=2, height=64, width=96
                ),
            )
        elif rama_prod == Rama_prod.Rama_Prod.uralvagon:
            return Prod_coefficients(
                number_coefficients=Text_coefficients(
                    length=5, height=64, width=160
                ),
                prod_coefficients=Text_coefficients(
                    length=1, height=64, width=64
                ),
                year_coefficients=Text_coefficients(
                    length=2, height=64, width=96
                ),
            )


import hashlib
import json
import os
import zipfile
from datetime import datetime

import cv2
import requests
from urllib.parse import urlencode
import torch

from data.neuro.letters_in_image import Letters_In_Image
from data.result import balka_prod
from data.result.Class_text import Class_text
from data.result.Label_area import Label_area
class Balka_text_cut_recognize_params:
    def __init__(self, length, height, width):
        self.length = length
        self.height = height
        self.width = width

class Balka_text_recognize_params:
    def __init__(self, number_params, prod_params, year_params):
        self.number_params = number_params
        self.prod_params = prod_params
        self.year_params = year_params

class Balka_Text_Recognize_yolo:

    def __init__(self, model_path, yolo_path):
        """reads yolov5 taught model from yandex-disk and includes it in class example"""
        self.model = torch.hub.load(yolo_path, 'custom', model_path, source='local')

        # for every text_class try to recognize text from all areas of text_class, number_params is depends on class and prod, returns string

    def work_image_cuts(self, number_image_cuts, l, h, w):
        """for every text_class try to recognize text from all areas of text_class, number_params is depends on class and prod, returns string """
        (str,conf) = ('', 0.0)
        for number_image_cut in number_image_cuts:
            # cv2.imwrite('data/neuro_classes/cut.jpg', number_image_cut)
            (cur_str, cur_conf) = self.work_img_word(number_image_cut, l, h, w)
            if len(cur_str) == l:
                if cur_conf > conf:
                    (str, conf) = (cur_str, cur_conf)
            elif len(cur_str) > len(str):
                (str, conf) = (cur_str, cur_conf)
            elif (len(cur_str) == len(str)) & (cur_conf > conf):
                (str, conf) = (cur_str, cur_conf)
        return (str, round(conf,2))

        # main_method takes all image_text_areas from image_rama_cut and recognize text

    def prepare_cuts(self, _balka_prod, image_cuts_2_half_balkas, class_text, has_prod = True):
        result_img_cuts = []
        if (_balka_prod == balka_prod.Balka_Prod.altai):
            if class_text == Class_text.number:
                if len(image_cuts_2_half_balkas) == 2:
                    for (number_img_cut) in image_cuts_2_half_balkas[0]:
                        result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_COUNTERCLOCKWISE))
                    for (number_img_cut) in image_cuts_2_half_balkas[1]:
                        result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_CLOCKWISE))
                    return result_img_cuts
                elif len(image_cuts_2_half_balkas) == 1:
                    if has_prod:
                        for (number_img_cut) in image_cuts_2_half_balkas[0]:
                            result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_COUNTERCLOCKWISE))
                    else:
                        for (number_img_cut) in image_cuts_2_half_balkas[0]:
                            result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_CLOCKWISE))
                    return result_img_cuts
                else:
                    return result_img_cuts
            elif class_text == Class_text.prod:
                for image_cuts in image_cuts_2_half_balkas:
                    for image_cut in image_cuts:
                        result_img_cuts.append(image_cut)
                return result_img_cuts
            elif class_text == Class_text.year:
                for image_cuts in image_cuts_2_half_balkas:
                    for image_cut in image_cuts:
                        result_img_cuts.append(image_cut)
                return result_img_cuts
        elif (_balka_prod == balka_prod.Balka_Prod.begickaya):
            if class_text == Class_text.number:
                if len(image_cuts_2_half_balkas) == 2:
                    for (number_img_cut) in image_cuts_2_half_balkas[0]:
                        result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_CLOCKWISE))
                    for (number_img_cut) in image_cuts_2_half_balkas[1]:
                        result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_COUNTERCLOCKWISE))
                    return result_img_cuts
                elif len(image_cuts_2_half_balkas) == 1:
                    if has_prod:
                        for (number_img_cut) in image_cuts_2_half_balkas[0]:
                            result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_CLOCKWISE))
                    else:
                        for (number_img_cut) in image_cuts_2_half_balkas[0]:
                            result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_COUNTERCLOCKWISE))
                    return result_img_cuts
                else:
                    return result_img_cuts
            elif class_text == Class_text.prod:
                for image_cuts in image_cuts_2_half_balkas:
                    for image_cut in image_cuts:
                        result_img_cuts.append(image_cut)
                return result_img_cuts
            elif class_text == Class_text.year:
                for image_cuts in image_cuts_2_half_balkas:
                    for image_cut in image_cuts:
                        result_img_cuts.append(image_cut)
                return result_img_cuts
        elif (_balka_prod == balka_prod.Balka_Prod.promlit):
            if class_text == Class_text.number:
                if len(image_cuts_2_half_balkas) == 2:
                    for (number_img_cut) in image_cuts_2_half_balkas[0]:
                        result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_CLOCKWISE))
                    for (number_img_cut) in image_cuts_2_half_balkas[1]:
                        result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_COUNTERCLOCKWISE))
                    return result_img_cuts
                elif len(image_cuts_2_half_balkas) == 1:
                    if has_prod:
                        for (number_img_cut) in image_cuts_2_half_balkas[0]:
                            result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_COUNTERCLOCKWISE))
                    else:
                        for (number_img_cut) in image_cuts_2_half_balkas[0]:
                            result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_CLOCKWISE))
                    return result_img_cuts
                else:
                    return result_img_cuts
            elif class_text == Class_text.prod:
                for image_cuts in image_cuts_2_half_balkas:
                    for image_cut in image_cuts:
                        result_img_cuts.append(image_cut)
                return result_img_cuts
            elif class_text == Class_text.year:
                for image_cuts in image_cuts_2_half_balkas:
                    for image_cut in image_cuts:
                        result_img_cuts.append(image_cut)
                return result_img_cuts
        elif (_balka_prod == balka_prod.Balka_Prod.ruzhimmash):
            if class_text == Class_text.number:
                if len(image_cuts_2_half_balkas) == 2:
                    for (number_img_cut) in image_cuts_2_half_balkas[0]:
                        result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_CLOCKWISE))
                    for (number_img_cut) in image_cuts_2_half_balkas[1]:
                        result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_COUNTERCLOCKWISE))
                    return result_img_cuts
                elif len(image_cuts_2_half_balkas) == 1:
                    if has_prod:
                        for (number_img_cut) in image_cuts_2_half_balkas[0]:
                            result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_CLOCKWISE))
                    else:
                        for (number_img_cut) in image_cuts_2_half_balkas[0]:
                            result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_COUNTERCLOCKWISE))
                    return result_img_cuts
                else:
                    return result_img_cuts
            elif class_text == Class_text.prod:
                for image_cuts in image_cuts_2_half_balkas:
                    for image_cut in image_cuts:
                        result_img_cuts.append(image_cut)
                return result_img_cuts
            elif class_text == Class_text.year:
                for image_cuts in image_cuts_2_half_balkas:
                    for image_cut in image_cuts:
                        result_img_cuts.append(image_cut)
                return result_img_cuts
        elif (_balka_prod == balka_prod.Balka_Prod.tihvin):
            if class_text == Class_text.number:
                if len(image_cuts_2_half_balkas) == 2:
                    for (number_img_cut) in image_cuts_2_half_balkas[0]:
                        result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_CLOCKWISE))
                    for (number_img_cut) in image_cuts_2_half_balkas[1]:
                        result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_COUNTERCLOCKWISE))
                    return result_img_cuts
                elif len(image_cuts_2_half_balkas) == 1:
                    if has_prod:
                        for (number_img_cut) in image_cuts_2_half_balkas[0]:
                            result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_CLOCKWISE))
                    else:
                        for (number_img_cut) in image_cuts_2_half_balkas[0]:
                            result_img_cuts.append(cv2.rotate(number_img_cut, cv2.ROTATE_90_COUNTERCLOCKWISE))
                    return result_img_cuts
                else:
                    return result_img_cuts
            elif class_text == Class_text.prod:
                for image_cuts in image_cuts_2_half_balkas:
                    for image_cut in image_cuts:
                        result_img_cuts.append(cv2.rotate(image_cut, cv2.ROTATE_90_CLOCKWISE))
                return result_img_cuts
            elif class_text == Class_text.year:
                for image_cuts in image_cuts_2_half_balkas:
                    for image_cut in image_cuts:
                        result_img_cuts.append(cv2.rotate(image_cut, cv2.ROTATE_90_CLOCKWISE))
                return result_img_cuts

    def work_image_cut(self, _balka_prod, image_text_areas_2_half_balkas, image_balka_cuts,
                       number_l, number_h, number_w, prod_l, prod_h, prod_w, year_l, year_h, year_w):
        """main_method takes all image_text_areas from image_rama_cut and recognize text"""
        i = 0
        number_image_cuts_2_half_balkas = []
        for image_text_areas in image_text_areas_2_half_balkas:
            number_image_rects = image_text_areas.areas[Class_text.number]
            image_rama_cut = image_balka_cuts[i]
            number_image_cuts_2_half_balkas.append(self.make_cuts(image_rama_cut, number_image_rects))
            i += 1
        has_prod = True
        if len(image_text_areas_2_half_balkas) == 1:
            has_prod = (len(image_text_areas_2_half_balkas[0].areas[Class_text.prod]) > 0)
        number_image_cuts = self.prepare_cuts(_balka_prod, number_image_cuts_2_half_balkas, Class_text.number, has_prod)
        (number, number_conf) = self.work_image_cuts(number_image_cuts, number_l, number_h, number_w)

        i = 0
        prod_image_cuts_2_half_balkas = []
        for image_text_areas in image_text_areas_2_half_balkas:
            prod_image_rects = image_text_areas.areas[Class_text.prod]
            image_rama_cut = image_balka_cuts[i]
            prod_image_cuts_2_half_balkas.append(self.make_cuts(image_rama_cut, prod_image_rects))
            i += 1
        has_prod = True
        prod_image_cuts = self.prepare_cuts(_balka_prod, prod_image_cuts_2_half_balkas, Class_text.prod, has_prod)
        (prod, prod_conf) = self.work_image_cuts(prod_image_cuts, prod_l, prod_h, prod_w)

        i = 0
        year_image_cuts_2_half_balkas = []
        for image_text_areas in image_text_areas_2_half_balkas:
            year_image_rects = image_text_areas.areas[Class_text.year]
            image_rama_cut = image_balka_cuts[i]
            year_image_cuts_2_half_balkas.append(self.make_cuts(image_rama_cut, year_image_rects))
            i += 1
        has_prod = True
        year_image_cuts = self.prepare_cuts(_balka_prod, year_image_cuts_2_half_balkas, Class_text.year, has_prod)
        (year, year_conf) = self.work_image_cuts(year_image_cuts, year_l, year_h, year_w)

        label_area = Label_area()
        label_area.labels[Class_text.number] = (number, number_conf)
        label_area.labels[Class_text.prod] = (prod, prod_conf)
        label_area.labels[Class_text.year] = (year, year_conf)
        return label_area

    def work_img_word(self, number_image_cut, l, number_h, number_w):
        h, w = number_image_cut.shape[:2]
        hash_object = hashlib.md5(bytes(str(datetime.now()), 'utf-8'))
        hash_str = hash_object.hexdigest()
        img_cut_path = 'cut_text_img' + hash_str + '.jpg'
        cv2.imwrite(img_cut_path, number_image_cut)
        self.model.max_det = l
        results = self.model(img_cut_path, size=(number_h, number_w))
        json_res = results.pandas().xyxy[0].to_json(orient="records")
        res2 = json.loads(json_res)
        img_letters = Letters_In_Image.get_letters_in_image_from_yolo_json(res2)
        img_letters.sort_letters()
        img_letters.delete_intersections()
        os.remove(img_cut_path)
        return img_letters.make_word(), img_letters.get_avg_conf()

    # cut text_areas imgs for each Rect from rect_array returns openCv imgs list
    def make_cuts(self, img_balka_cut, rect_array):
        """cut text_areas imgs for each Rect from rect_array returns openCv imgs list"""
        number_image_cuts = []
        for rect in rect_array:
            number_image_cuts.append(img_balka_cut[rect.ymin:rect.ymax, rect.xmin:rect.xmax])
        return number_image_cuts
        



import hashlib
import os
from datetime import datetime

import cv2

from data.neuro.Vagon_number_detect_class import Vagon_number_detect_class
from data.neuro.Vagon_number_recognize_yolo import Vagon_number_recognize_yolo
from data.neuro.local_models import *
from data.neuro.models import *


class Danila_vagon_text_recognize_base:
    def __init__(self, local, yolov5_dir, danila_vagon_text_recognize_params):


        print('reading and loading - VAGON_NUMBER_RECOGNIZE_MODEL')
        if local:
            if danila_vagon_text_recognize_params.vagon_text_recognize_version == 1:
                self.vagon_number_recognize_model = Vagon_number_recognize_yolo(local, LOCAL_VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS, yolov5_dir)
            elif danila_vagon_text_recognize_params.vagon_text_recognize_version == 2:
                self.vagon_number_recognize_model = Vagon_number_recognize_yolo(local, LOCAL_VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_2, yolov5_dir)
            elif danila_vagon_text_recognize_params.vagon_text_recognize_version == 3:
                self.vagon_number_recognize_model = Vagon_number_recognize_yolo(local, LOCAL_VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_3, yolov5_dir)
            elif danila_vagon_text_recognize_params.vagon_text_recognize_version == 4:
                self.vagon_number_recognize_model = Vagon_number_recognize_yolo(local, LOCAL_VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_4, yolov5_dir)
        else:
            if danila_vagon_text_recognize_params.vagon_text_recognize_version == 1:
                self.vagon_number_recognize_model = Vagon_number_recognize_yolo(local, VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS, yolov5_dir)
            elif danila_vagon_text_recognize_params.vagon_text_recognize_version == 2:
                self.vagon_number_recognize_model = Vagon_number_recognize_yolo(local, VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_2, yolov5_dir)
            elif danila_vagon_text_recognize_params.vagon_text_recognize_version == 3:
                self.vagon_number_recognize_model = Vagon_number_recognize_yolo(local, VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_3, yolov5_dir)
            elif danila_vagon_text_recognize_params.vagon_text_recognize_version == 4:
                self.vagon_number_recognize_model = Vagon_number_recognize_yolo(local, VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_4, yolov5_dir)
        self.danila_vagon_text_recognize_params = danila_vagon_text_recognize_params


    def vagon_number_recognize(self, img, vagon_number_rects):
        return self.vagon_number_recognize_model.work_image(img, vagon_number_rects,
            self.danila_vagon_text_recognize_params.vagon_text_recognize_size_h,
            self.danila_vagon_text_recognize_params.vagon_text_recognize_size_w
                                                            )



import json
import os
import zipfile

import cv2
import requests
from urllib.parse import urlencode
import torch
import hashlib
from datetime import datetime
from data.neuro.letters_in_image import Letters_In_Image
from data.neuro.objs_in_image import Objs_In_Image
from data.result.Class_text import Class_text
from data.result.Label_area import Label_area
from data.result.Rama_prod import Rama_Prod, Rama_Prod_Conf
from data.result.balka_prod import Balka_Prod_Conf, Balka_Prod


class Balka_prod_classify_class_dop_detect:

    def __init__(self, model_path, model_detect_path, yolo_path):
        """reads yolov5 taught model from yandex-disk and includes it in class example"""
        self.model = torch.hub.load(yolo_path, 'custom', model_path, source='local')
        self.model_detect = torch.hub.load(yolo_path, 'custom', model_detect_path, source='local')
        # for every text_class try to recognize text from all areas of text_class, number_params is depends on class and prod, returns string


    def work_image(self, img, size, size_detect):
        hash_object = hashlib.md5(bytes(str(datetime.now()), 'utf-8'))
        hash_str = hash_object.hexdigest()
        img_name = 'img' + hash_str + '.jpg'
        cv2.imwrite(img_name, img)
        results = self.model([img_name], size = size)
        json_res = results.pandas().xyxy[0].to_json(orient="records")
        res2 = json.loads(json_res)
        if len(res2) == 0:
            results_balka = self.model_detect([img_name])
            json_res_balka = results_balka.pandas().xyxy[0].to_json(orient="records")
            res2_balka = json.loads(json_res_balka)
            if len(res2_balka) == 0:
                result = Balka_Prod_Conf(Balka_Prod(5), 0.0)
            else:
                prods = []
                i = 1
                for balka in res2_balka:
                    balka_img = img[int(balka['ymin']):int(balka['ymax']), int(balka['xmin']):int(balka['xmax'])]
                    cv2.imwrite(str(i) + 'balka.jpg', balka_img)
                    results_3 = self.model([str(i) + 'balka.jpg'], size=size_detect)
                    json_res_3 = results_3.pandas().xyxy[0].to_json(orient="records")
                    res3 = json.loads(json_res_3)
                    if len(res3) > 0:
                        prods.append(res3[0])
                    os.remove(str(i) + 'balka.jpg')
                    i += 1
                prods.sort(key=lambda prod: prod['confidence'], reverse=True)
                if len(prods) == 0:
                    result = Balka_Prod_Conf(Balka_Prod(5), 0.0)
                else:
                    res2 = prods
                    res_index = res2[0]['class']
                    res_conf = res2[0]['confidence']
                    result = Balka_Prod_Conf(Balka_Prod(res_index), res_conf)
        else:
            res_index = res2[0]['class']
            res_conf = res2[0]['confidence']
            result = Balka_Prod_Conf(Balka_Prod(res_index), res_conf)
        os.remove(img_name)
        return result

    def classify(self, img, size, size_detect):
        self.model.max_det = 1
        balka_prod_conf = self.work_image(img, size, size_detect)
        return balka_prod_conf


class Danila_vagon_params:
    def __init__(self, danila_vagon_text_detect_params, danila_vagon_text_recognize_params):
        self.danila_vagon_text_detect_params = danila_vagon_text_detect_params
        self.danila_vagon_text_recognize_params = danila_vagon_text_recognize_params



class Danila_rama_params:
    def __init__(self, danila_rama_classify_params, danila_rama_text_detect_params, danila_rama_text_recognize_params):
        self.danila_rama_classify_params = danila_rama_classify_params
        self.danila_rama_text_detect_params = danila_rama_text_detect_params
        self.danila_rama_text_recognize_params = danila_rama_text_recognize_params